% function y = linshoot(a,b,n,alpha,beta,f)
%
% Linear shooting method for a linear problem
%
%   y'' = f(t,y,y') (Assumed linear)
%   y(a) = alpha
%   y(b) = beta
% 
% Inputs
%  a,b    time interval
%
%  n      number of time subintervals
%
%  alpha  = y(a)
%
%  beta   = y(b)
%
%  f      function handle, for a problem assumed LINEAR. 
%         example:
%
%         f = @(t,y,yp) -3*yp +2*y+2*t+3; 
%
%         the parameters are (in this order)
%         t   space variable
%         y   y(t)
%         yp  y'(t)
%
% Outputs
%  y      function y at the points t = a + i*(b-a)/n, i=0..n.
function y = linshoot(a,b,n,alpha,beta,f)
F = @(t,y) % function handle to be given to RK4
y0 = % initial condition for RK4

% solve first order system
yt = rk4(a,b,n,y0,F);

% extract solution to linear BVP from solution to system
lambda =  % TO BE COMPLETED
y = % TO BE COMPLETED
